@@ -454,14 +454,12 @@ def setup(config):
         script = LandscapeSetupScript(config)
         script.run()
 
+    # WARNING: ssl_public_key is misnamed, it's not the key of the certificate,
+    # but the actual certificate itself.
     if config.ssl_public_key and config.ssl_public_key.startswith("base64:"):
-        key_filename = config.get_config_filename() + ".ssl_public_key"
-        print_text("Writing SSL CA certificate to %s..." % key_filename)
-        decoded_key = base64.decodestring(config.ssl_public_key[7:])
-        key_file = open(key_filename, "w")
-        key_file.write(decoded_key)
-        key_file.close()
-        config.ssl_public_key = key_filename
+        decoded_cert = base64.decodestring(config.ssl_public_key[7:])
+        config.ssl_public_key = store_public_key_data(
+            config, decoded_cert)
 
     config.write()
     # Restart the client to ensure that it's using the new configuration.
@@ -478,6 +476,26 @@ def setup(config):
             sys.exit(exit_code)
 
 
+def store_public_key_data(config, certificate_data):
+    """
+    Write out the data from the SSL certificate provided to us, either from a
+    bootstrap.conf file, or from EC2-style user-data.
+
+    @param config:  The L{BrokerConfiguration} object in use.
+    @param certificate_data: a string of data that represents the contents of
+    the file to be written.
+    @return the L{BrokerConfiguration} object that was passed in, updated to
+    reflect the path of the ssl_public_key file.
+    """
+    key_filename = os.path.join(config.data_path,
+        os.path.basename(config.get_config_filename() + ".ssl_public_key"))
+    print_text("Writing SSL CA certificate to %s..." % key_filename)
+    key_file = open(key_filename, "w")
+    key_file.write(certificate_data)
+    key_file.close()
+    return key_filename
+
+
 def register(config, reactor=None):
     """Instruct the Landscape Broker to register the client.
 
@@ -589,16 +607,21 @@ def fetch_import_url(url):
 
 
 def main(args):
+    config = LandscapeSetupConfiguration(fetch_import_url)
+    if args in (["-h"], ["--help"]):
+        # We let landscape-config --help to be run as normal user
+        config.load(args)
+
     if os.getuid() != 0:
         sys.exit("landscape-config must be run as root.")
 
-    config = LandscapeSetupConfiguration(fetch_import_url)
     try:
         config.load(args)
     except ImportOptionError, error:
         print_text(str(error), error=True)
         sys.exit(1)
 
+
     # Disable startup on boot and stop the client, if one is running.
     if config.disable:
         stop_client_and_disable_init_script()
