@@ -1,34 +1,27 @@
+import os
+
 from twisted.internet.defer import fail
 
-from landscape.lib.persist import Persist
-from landscape.lib.dbus_util import get_object
-
-from landscape.monitor.monitor import MonitorPluginRegistry
-from landscape.monitor.usermonitor import UserMonitor, UserMonitorDBusObject
-from landscape.manager.usermanager import UserManagerDBusObject
+from landscape.monitor.usermonitor import (
+    UserMonitor, RemoteUserMonitorConnector)
+from landscape.manager.usermanager import (
+    UserManager, UserManagerProtocolFactory)
 from landscape.user.tests.helpers import FakeUserProvider
-from landscape.tests.helpers import LandscapeIsolatedTest
-from landscape.tests.helpers import RemoteBrokerHelper
+from landscape.tests.helpers import LandscapeTest, MonitorHelper
 from landscape.tests.mocker import ANY
 
 
-class UserMonitorNoManagerTest(LandscapeIsolatedTest):
+class UserMonitorNoManagerTest(LandscapeTest):
 
-    helpers = [RemoteBrokerHelper]
-
-    def setUp(self):
-        super(UserMonitorNoManagerTest, self).setUp()
-        self.persist = Persist()
-        self.monitor = MonitorPluginRegistry(
-            self.remote, self.broker_service.reactor,
-            self.broker_service.config, self.broker_service.bus, self.persist)
+    helpers = [MonitorHelper]
 
     def test_no_fetch_users_in_monitor_only_mode(self):
         """
         If we're in monitor_only mode, then all users are assumed to be
         unlocked.
         """
-        self.broker_service.config.monitor_only = True
+        self.config.monitor_only = True
+
         def got_result(result):
             self.assertMessages(
                 self.broker_service.message_store.get_pending_messages(),
@@ -39,37 +32,41 @@ class UserMonitorNoManagerTest(LandscapeIsolatedTest):
                                     "primary-gid": 1000, "uid": 1000,
                                     "username": u"jdoe", "work-phone": None}],
                                     "type": "users"}])
+            plugin.stop()
 
         users = [("jdoe", "x", 1000, 1000, "JD,,,,", "/home/jdoe", "/bin/sh")]
         groups = [("webdev", "x", 1000, ["jdoe"])]
         provider = FakeUserProvider(users=users, groups=groups)
         plugin = UserMonitor(provider=provider)
-        self.monitor.add(plugin)
+        plugin.register(self.monitor)
         self.broker_service.message_store.set_accepted_types(["users"])
         result = plugin.run()
         result.addCallback(got_result)
         return result
 
 
-class UserMonitorTest(LandscapeIsolatedTest):
+class UserMonitorTest(LandscapeTest):
 
-    helpers = [RemoteBrokerHelper]
+    helpers = [MonitorHelper]
 
     def setUp(self):
         super(UserMonitorTest, self).setUp()
-        self.persist = Persist()
-        self.monitor = MonitorPluginRegistry(
-            self.remote, self.broker_service.reactor,
-            self.broker_service.config, self.broker_service.bus,
-            self.persist)
-        self.shadow_file = self.makeFile("""\
-jdoe:$1$xFlQvTqe$cBtrNEDOIKMy/BuJoUdeG0:13348:0:99999:7:::
-psmith:!:13348:0:99999:7:::
-sbarnes:$1$q7sz09uw$q.A3526M/SHu8vUb.Jo1A/:13349:0:99999:7:::
-""")
+        self.shadow_file = self.makeFile(
+            "jdoe:$1$xFlQvTqe$cBtrNEDOIKMy/BuJoUdeG0:13348:0:99999:7:::\n"
+            "psmith:!:13348:0:99999:7:::\n"
+            "sam:$1$q7sz09uw$q.A3526M/SHu8vUb.Jo1A/:13349:0:99999:7:::\n")
+        self.user_manager = UserManager(shadow_file=self.shadow_file)
+        factory = UserManagerProtocolFactory(object=self.user_manager)
+        socket = os.path.join(self.config.sockets_path,
+                              UserManager.name + ".sock")
+        self.port = self.reactor.listen_unix(socket, factory)
+        self.provider = FakeUserProvider()
+        self.plugin = UserMonitor(self.provider)
 
-        self.service = UserManagerDBusObject(self.broker_service.bus,
-                                             shadow_file=self.shadow_file)
+    def tearDown(self):
+        self.port.stopListening()
+        self.plugin.stop()
+        return super(UserMonitorTest, self).tearDown()
 
     def test_constants(self):
         """
@@ -77,15 +74,15 @@ sbarnes:$1$q7sz09uw$q.A3526M/SHu8vUb.Jo1A/:13349:0:99999:7:::
         L{UserMonitor.run_interval} need to be present for
         L{Plugin} to work properly.
         """
-        plugin = UserMonitor(FakeUserProvider())
-        self.assertEquals(plugin.persist_name, "users")
-        self.assertEquals(plugin.run_interval, 3600)
+        self.assertEquals(self.plugin.persist_name, "users")
+        self.assertEquals(self.plugin.run_interval, 3600)
 
     def test_wb_resynchronize_event(self):
         """
         When a C{resynchronize} event occurs any cached L{UserChange}
         snapshots should be cleared and a new message with users generated.
         """
+
         def resynchronize_complete(result, plugin):
 
             def resynchronization_new_messages(result):
@@ -118,14 +115,13 @@ sbarnes:$1$q7sz09uw$q.A3526M/SHu8vUb.Jo1A/:13349:0:99999:7:::
             deferred.addCallback(resynchronization_new_messages)
             return deferred
 
-        users = [("jdoe", "x", 1000, 1000, "JD,,,,", "/home/jdoe", "/bin/sh")]
-        groups = [("webdev", "x", 1000, ["jdoe"])]
+        self.provider.users = [("jdoe", "x", 1000, 1000, "JD,,,,",
+                                "/home/jdoe", "/bin/sh")]
+        self.provider.groups = [("webdev", "x", 1000, ["jdoe"])]
         self.broker_service.message_store.set_accepted_types(["users"])
-        provider = FakeUserProvider(users=users, groups=groups)
-        plugin = UserMonitor(provider=provider)
-        self.monitor.add(plugin)
-        deferred = plugin.run()
-        deferred.addCallback(resynchronize_complete, plugin)
+        self.monitor.add(self.plugin)
+        deferred = self.plugin.run()
+        deferred.addCallback(resynchronize_complete, self.plugin)
         return deferred
 
     def test_run(self):
@@ -134,6 +130,7 @@ sbarnes:$1$q7sz09uw$q.A3526M/SHu8vUb.Jo1A/:13349:0:99999:7:::
         message with  a diff-like representation of changes since the last
         run.
         """
+
         def got_result(result):
             self.assertMessages(
                 self.broker_service.message_store.get_pending_messages(),
@@ -145,13 +142,12 @@ sbarnes:$1$q7sz09uw$q.A3526M/SHu8vUb.Jo1A/:13349:0:99999:7:::
                                     "username": u"jdoe", "work-phone": None}],
                                     "type": "users"}])
 
-        users = [("jdoe", "x", 1000, 1000, "JD,,,,", "/home/jdoe", "/bin/sh")]
-        groups = [("webdev", "x", 1000, ["jdoe"])]
-        provider = FakeUserProvider(users=users, groups=groups)
-        plugin = UserMonitor(provider=provider)
-        self.monitor.add(plugin)
+        self.provider.users = [("jdoe", "x", 1000, 1000, "JD,,,,",
+                                "/home/jdoe", "/bin/sh")]
+        self.provider.groups = [("webdev", "x", 1000, ["jdoe"])]
         self.broker_service.message_store.set_accepted_types(["users"])
-        result = plugin.run()
+        self.monitor.add(self.plugin)
+        result = self.plugin.run()
         result.addCallback(got_result)
         return result
 
@@ -161,17 +157,13 @@ sbarnes:$1$q7sz09uw$q.A3526M/SHu8vUb.Jo1A/:13349:0:99999:7:::
         super class, which sets up a looping call to run the plugin
         every L{UserMonitor.run_interval} seconds.
         """
-        provider = FakeUserProvider(users=[], groups=[])
-        plugin = UserMonitor(provider=provider)
-
-        mock_plugin = self.mocker.patch(plugin)
-        mock_plugin.run()
-        self.mocker.count(5)
+        self.plugin.run = self.mocker.mock()
+        self.expect(self.plugin.run()).count(5)
         self.mocker.replay()
+        self.monitor.add(self.plugin)
 
-        self.monitor.add(plugin)
         self.broker_service.message_store.set_accepted_types(["users"])
-        self.monitor.reactor.advance(plugin.run_interval*5)
+        self.reactor.advance(self.plugin.run_interval * 5)
 
     def test_run_with_operation_id(self):
         """
@@ -179,6 +171,7 @@ sbarnes:$1$q7sz09uw$q.A3526M/SHu8vUb.Jo1A/:13349:0:99999:7:::
         message with  a diff-like representation of changes since the last
         run.
         """
+
         def got_result(result):
             self.assertMessages(
                 self.broker_service.message_store.get_pending_messages(),
@@ -192,18 +185,17 @@ sbarnes:$1$q7sz09uw$q.A3526M/SHu8vUb.Jo1A/:13349:0:99999:7:::
                                     "type": "users"}])
 
 
-        users = [("jdoe", "x", 1000, 1000, "JD,,,,", "/home/jdoe", "/bin/sh")]
-        groups = [("webdev", "x", 1000, ["jdoe"])]
-        provider = FakeUserProvider(users=users, groups=groups)
-
-        plugin = UserMonitor(provider=provider)
-        self.monitor.add(plugin)
+        self.provider.users = [("jdoe", "x", 1000, 1000, "JD,,,,",
+                                "/home/jdoe", "/bin/sh")]
+        self.provider.groups = [("webdev", "x", 1000, ["jdoe"])]
+        self.monitor.add(self.plugin)
         self.broker_service.message_store.set_accepted_types(["users"])
-        result = plugin.run(1001)
+        result = self.plugin.run(1001)
         result.addCallback(got_result)
         return result
 
     def test_detect_changes(self):
+
         def got_result(result):
             self.assertMessages(
                 self.broker_service.message_store.get_pending_messages(),
@@ -216,16 +208,16 @@ sbarnes:$1$q7sz09uw$q.A3526M/SHu8vUb.Jo1A/:13349:0:99999:7:::
                   "type": "users"}])
 
         self.broker_service.message_store.set_accepted_types(["users"])
-        users = [("jdoe", "x", 1000, 1000, "JD,,,,", "/home/jdoe", "/bin/sh")]
-        groups = [("webdev", "x", 1000, ["jdoe"])]
-        provider = FakeUserProvider(users=users, groups=groups)
+        self.provider.users = [("jdoe", "x", 1000, 1000, "JD,,,,",
+                                "/home/jdoe", "/bin/sh")]
+        self.provider.groups = [("webdev", "x", 1000, ["jdoe"])]
 
-        plugin = UserMonitor(provider=provider)
-        self.monitor.add(plugin)
-        remote_service = get_object(self.broker_service.bus,
-            UserMonitorDBusObject.bus_name, UserMonitorDBusObject.object_path)
-        result = remote_service.detect_changes()
+        self.monitor.add(self.plugin)
+        connector = RemoteUserMonitorConnector(self.reactor, self.config)
+        result = connector.connect()
+        result.addCallback(lambda remote: remote.detect_changes())
         result.addCallback(got_result)
+        result.addCallback(lambda x: connector.disconnect())
         return result
 
     def test_detect_changes_with_operation_id(self):
@@ -233,6 +225,7 @@ sbarnes:$1$q7sz09uw$q.A3526M/SHu8vUb.Jo1A/:13349:0:99999:7:::
         The L{UserMonitor} should expose a remote
         C{remote_run} method which should call the remote
         """
+
         def got_result(result):
             self.assertMessages(
                 self.broker_service.message_store.get_pending_messages(),
@@ -246,17 +239,15 @@ sbarnes:$1$q7sz09uw$q.A3526M/SHu8vUb.Jo1A/:13349:0:99999:7:::
                   "type": "users"}])
 
         self.broker_service.message_store.set_accepted_types(["users"])
-        users = [("jdoe", "x", 1000, 1000, "JD,,,,", "/home/jdoe", "/bin/sh")]
-        groups = [("webdev", "x", 1000, ["jdoe"])]
-        provider = FakeUserProvider(users=users, groups=groups)
-
-        plugin = UserMonitor(provider=provider)
-        self.monitor.add(plugin)
-
-        remote_service = get_object(self.broker_service.bus,
-            UserMonitorDBusObject.bus_name, UserMonitorDBusObject.object_path)
-        result = remote_service.detect_changes(1001)
+        self.provider.users = [("jdoe", "x", 1000, 1000, "JD,,,,",
+                                "/home/jdoe", "/bin/sh")]
+        self.provider.groups = [("webdev", "x", 1000, ["jdoe"])]
+        self.monitor.add(self.plugin)
+        connector = RemoteUserMonitorConnector(self.reactor, self.config)
+        result = connector.connect()
+        result.addCallback(lambda remote: remote.detect_changes(1001))
         result.addCallback(got_result)
+        result.addCallback(lambda x: connector.disconnect())
         return result
 
     def test_no_message_if_not_accepted(self):
@@ -264,6 +255,7 @@ sbarnes:$1$q7sz09uw$q.A3526M/SHu8vUb.Jo1A/:13349:0:99999:7:::
         Don't add any messages at all if the broker isn't currently
         accepting their type.
         """
+
         def got_result(result):
             mstore = self.broker_service.message_store
             self.assertMessages(list(mstore.get_pending_messages()), [])
@@ -271,19 +263,19 @@ sbarnes:$1$q7sz09uw$q.A3526M/SHu8vUb.Jo1A/:13349:0:99999:7:::
             self.assertMessages(list(mstore.get_pending_messages()), [])
 
         self.broker_service.message_store.set_accepted_types([])
-        users = [("jdoe", "x", 1000, 1000, "JD,,,,", "/home/jdoe", "/bin/sh")]
-        groups = [("webdev", "x", 1000, ["jdoe"])]
-        provider = FakeUserProvider(users=users, groups=groups)
-
-        plugin = UserMonitor(provider=provider)
-        self.monitor.add(plugin)
-        remote_service = get_object(self.broker_service.bus,
-            UserMonitorDBusObject.bus_name, UserMonitorDBusObject.object_path)
-        result = remote_service.detect_changes(1001)
+        self.provider.users = [("jdoe", "x", 1000, 1000, "JD,,,,",
+                                "/home/jdoe", "/bin/sh")]
+        self.provider.groups = [("webdev", "x", 1000, ["jdoe"])]
+        self.monitor.add(self.plugin)
+        connector = RemoteUserMonitorConnector(self.reactor, self.config)
+        result = connector.connect()
+        result.addCallback(lambda remote: remote.detect_changes(1001))
         result.addCallback(got_result)
+        result.addCallback(lambda x: connector.disconnect())
         return result
 
     def test_call_on_accepted(self):
+
         def got_result(result):
             mstore = self.broker_service.message_store
             self.assertMessages(mstore.get_pending_messages(),
@@ -295,15 +287,13 @@ sbarnes:$1$q7sz09uw$q.A3526M/SHu8vUb.Jo1A/:13349:0:99999:7:::
                                     "username": u"jdoe", "work-phone": None}],
                   "type": "users"}])
 
-        users = [("jdoe", "x", 1000, 1000, "JD,,,,", "/home/jdoe", "/bin/sh")]
-        groups = [("webdev", "x", 1000, ["jdoe"])]
-        provider = FakeUserProvider(users=users, groups=groups)
-
-        plugin = UserMonitor(provider=provider)
-        self.monitor.add(plugin)
+        self.provider.users = [("jdoe", "x", 1000, 1000, "JD,,,,",
+                                "/home/jdoe", "/bin/sh")]
+        self.provider.groups = [("webdev", "x", 1000, ["jdoe"])]
+        self.monitor.add(self.plugin)
 
         self.broker_service.message_store.set_accepted_types(["users"])
-        result = self.broker_service.reactor.fire(
+        result = self.reactor.fire(
             ("message-type-acceptance-changed", "users"), True)
         result = [x for x in result if x][0]
         result.addCallback(got_result)
@@ -317,27 +307,27 @@ sbarnes:$1$q7sz09uw$q.A3526M/SHu8vUb.Jo1A/:13349:0:99999:7:::
         sent by the plugin has been sent.
         """
         self.log_helper.ignore_errors(RuntimeError)
+
         def got_result(result):
-            persist = plugin._persist
+            persist = self.plugin._persist
             mstore = self.broker_service.message_store
             self.assertMessages(mstore.get_pending_messages(), [])
             self.assertFalse(persist.get("users"))
             self.assertFalse(persist.get("groups"))
 
         self.broker_service.message_store.set_accepted_types(["users"])
-        broker_mock = self.mocker.replace(self.monitor.broker)
-        broker_mock.send_message(ANY, urgent=True)
+        self.monitor.broker.send_message = self.mocker.mock()
+        self.monitor.broker.send_message(ANY, urgent=True)
         self.mocker.result(fail(RuntimeError()))
         self.mocker.replay()
 
-        users = [("jdoe", "x", 1000, 1000, "JD,,,,", "/home/jdoe", "/bin/sh")]
-        groups = [("webdev", "x", 1000, ["jdoe"])]
-        provider = FakeUserProvider(users=users, groups=groups)
-        plugin = UserMonitor(provider=provider)
-        self.monitor.add(plugin)
-        remote_service = get_object(self.broker_service.bus,
-            UserMonitorDBusObject.bus_name, UserMonitorDBusObject.object_path)
-        result = remote_service.detect_changes(1001)
+        self.provider.users = [("jdoe", "x", 1000, 1000, "JD,,,,",
+                       "/home/jdoe", "/bin/sh")]
+        self.provider.groups = [("webdev", "x", 1000, ["jdoe"])]
+        self.monitor.add(self.plugin)
+        connector = RemoteUserMonitorConnector(self.reactor, self.config)
+        result = connector.connect()
+        result.addCallback(lambda remote: remote.detect_changes(1001))
         result.addCallback(got_result)
-
+        result.addCallback(lambda x: connector.disconnect())
         return result
