@@ -23,8 +23,14 @@ class SysVConfig(object):
             raise ProcessError("Could not stop client")
 
     def is_configured_to_run(self):
+        """
+        Return a boolean representing whether the init script will decide to
+        actually start the client when it is run.  This method should match
+        the semantics of the checks in debian/landscape-client.init.
+        """
         state = self._parse_file()
-        return bool(state.get("RUN", None))
+        run_value = state.get("RUN", "0")
+        return (not run_value[:1].isspace()) and run_value != "0"
 
     def _parse_file(self):
         values = {}
@@ -32,8 +38,9 @@ class SysVConfig(object):
         if os.path.isfile(self._filename):
             for line in open(self._filename, "r"):
                 line = line.strip()
-                key, value = line.split("=")
-                values[key] = value
+                if "=" in line:
+                    key, value = line.split("=")
+                    values[key] = value
         return values
 
     def _write_file(self, values):
